package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public class MethodParameter implements Cloneable
{
    private int nameIndex;
    private int accessFlags;
    
    public MethodParameter() {
    }
    
    MethodParameter(final DataInput input) throws IOException {
        this.nameIndex = input.readUnsignedShort();
        this.accessFlags = input.readUnsignedShort();
    }
    
    public void accept(final Visitor v) {
        v.visitMethodParameter(this);
    }
    
    public MethodParameter copy() {
        try {
            return (MethodParameter)this.clone();
        }
        catch (final CloneNotSupportedException ex) {
            return null;
        }
    }
    
    public final void dump(final DataOutputStream file) throws IOException {
        file.writeShort(this.nameIndex);
        file.writeShort(this.accessFlags);
    }
    
    public int getAccessFlags() {
        return this.accessFlags;
    }
    
    public int getNameIndex() {
        return this.nameIndex;
    }
    
    public String getParameterName(final ConstantPool constantPool) {
        if (this.nameIndex == 0) {
            return null;
        }
        return constantPool.getConstantUtf8(this.nameIndex).getBytes();
    }
    
    public boolean isFinal() {
        return (this.accessFlags & 0x10) != 0x0;
    }
    
    public boolean isMandated() {
        return (this.accessFlags & 0xFFFF8000) != 0x0;
    }
    
    public boolean isSynthetic() {
        return (this.accessFlags & 0x1000) != 0x0;
    }
    
    public void setAccessFlags(final int accessFlags) {
        this.accessFlags = accessFlags;
    }
    
    public void setNameIndex(final int nameIndex) {
        this.nameIndex = nameIndex;
    }
}
